<?php
namespace Claromentis\Core\Mail\Receive\Contract;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array();




interface MailMessage
{
    
    
    
    
    
    
    public function GetSenderAddress() : string;
    
    
    
    
    
    
    
    public function GetRecipientAddress() : string;
    
    
    
    
    public function GetSubject() : string;
    
    
    
    
    
    
    public function GetFrom() : string;
    
    
    
    
    
    
    
    public function GetTo() : string;
    
    
    
    
    
    
    
    public function GetBodyHtml() : string;
    
    
    
    
    
    
    
    public function GetBodyText() : string;
    
    
    
    
    public function GetDate() : \Date;
    
    
    
    
    public function GetAttachments();
}