<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] ?: array()) + array("_03b1f0cee835582d1158d" . "ce2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJzY3J" . "pYmVy"), "_a3d82c5df38e194c9c73e3ccb42" . "23bbc" => base64_decode("ZW1haWxfZGF0YQ" . "=="), "_bfda889b74ea561b14325e30" . "e7d75426" => base64_decode("Ym9k" . "eV9o" . "dG1s"), "_ced92d7b391285c8a26846f1" . "f4bd3128" => base64_decode("Ym9" . "keV" . "90Z" . "Xh0"), "_376d30c40857357a4d4cbb1ffaa25" . "817" => base64_decode("dG" . "8="), "_5d40a2cf1c525fb252bf5599" . "e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMg" . "aWRlbnRpZmllZCBmb3IgbWFpbDsgc3ViamVj" . "dCAn"), "_9b16fa2683095e67d7c8b265a808" . "1d0b" => base64_decode("TWFpbFJlY2VpdmVkR" . "XZlbnRSZWNlaXZlcg" . "=="), "_67a0d624aebcceb0abd5ce56a5" . "3ff06f" => base64_decode("ZGF0ZQ" . "=="), "_c35473364fa7" . "a050299058f33" . "2ec29c1" => base64_decode("ZXhjZXB0a" . "W9u"), "_e608e5b5c4c" . "34a67ba97ef8" . "4c1e16199" => base64_decode("J" . "w" . "=" . "="), "projec" . "t_id" => base64_decode("cHJvamVjdF9pZA" . "=="), "_618a4aeb9fecc45" . "92a4521f34876fa2" . "9" => base64_decode("ZnJ" . "vbQ" . "=="), "_460e1aeb3113a" . "1676ce59a8f404" . "31d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYX" . "B0dXJlIHByb2plY3Q="), "_f656816961e8573806141c558b184fe" . "2" => base64_decode("c3V" . "iam" . "Vjd" . "A=="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_9b16fa2683095e6" . "7d7c8b265a8081d0" . "b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_03b1f0cee835582d" . "1158dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_5d40a2c" . "f1c525fb" . "252bf559" . "9e339fdd" . "0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_e608e5b5c4c34a67ba97ef84c1" . "e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_618a4aeb9fecc45" . "92a4521f34876fa2" . "9"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_376d30c40857357a4d4cb" . "b1ffaa25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_f65681696" . "1e85738061" . "41c558b184" . "fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_ced92d7b" . "391285c8a" . "26846f1f4" . "bd3128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_bfda889b74ea561" . "b14325e30e7d7542" . "6"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_67a0d624aebcceb0abd5ce56a53ff0" . "6f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_460e1aeb3113a1676ce59a8f4" . "0431d5c"], [$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["project_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_a3d82c5df3" . "8e194c9c73e" . "3ccb4223bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_c35473364f" . "a7a05029905" . "8f332ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}